define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "this qtr.",
	"dateTimeFormats-appendItem-Year": "{0} {1}",
	"field-quarter-short-relative+1": "next qtr.",
	"dayPeriods-standAlone-abbr-noon": "noon",
	"field-tue-relative+-1": "last Tuesday",
	"field-year": "year",
	"dateFormatItem-yw": "'week' w 'of' Y",
	"dayPeriods-format-abbr-afternoon1": "in the afternoon",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-ms": "mm:ss",
	"timeFormat-short": "h:mm a",
	"field-minute": "minute",
	"field-tue-narrow-relative+0": "this Tu",
	"field-tue-narrow-relative+1": "next Tu",
	"field-thu-short-relative+0": "this Thu.",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "next Thu.",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-wed-narrow-relative+-1": "last W",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-era-short": "era",
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-weekdayOfMonth": "weekday of the month",
	"field-second-short": "sec.",
	"dayPeriods-format-narrow-am": "a",
	"dayPeriods-standAlone-abbr-morning1": "morning",
	"dateFormatItem-MMMd": "MMM d",
	"dayPeriods-format-narrow-morning1": "in the morning",
	"dayPeriods-format-abbr-am": "AM",
	"field-week-relative+0": "this week",
	"field-month-relative+0": "this month",
	"field-week-relative+1": "next week",
	"field-month-relative+1": "next month",
	"field-sun-narrow-relative+0": "this Su",
	"timeFormat-medium": "h:mm:ss a",
	"field-mon-short-relative+0": "this Mon.",
	"field-sun-narrow-relative+1": "next Su",
	"field-mon-short-relative+1": "next Mon.",
	"field-second-relative+0": "now",
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"dayPeriods-standAlone-wide-noon": "noon",
	"eraNames": [
		"Before Christ",
		"Anno Domini"
	],
	"field-weekOfMonth": "week of month",
	"dayPeriods-standAlone-abbr-pm": "PM",
	"field-month-short": "mo.",
	"dateFormatItem-GyMMMEd": "E, MMM d, y G",
	"field-day": "day",
	"dayPeriods-standAlone-wide-night1": "night",
	"field-dayOfYear-short": "day of yr.",
	"field-year-relative+-1": "last year",
	"dayPeriods-format-wide-am": "AM",
	"field-sat-short-relative+-1": "last Sat.",
	"dayPeriods-format-narrow-afternoon1": "in the afternoon",
	"dayPeriods-format-wide-afternoon1": "in the afternoon",
	"field-hour-relative+0": "this hour",
	"field-second-short-relative+0": "now",
	"field-wed-relative+-1": "last Wednesday",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "last Sa",
	"field-second": "second",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "MMMM d, y",
	"dateFormatItem-GyMMMd": "MMM d, y G",
	"dayPeriods-standAlone-abbr-midnight": "midnight",
	"field-quarter": "quarter",
	"field-week-short": "wk.",
	"dayPeriods-format-narrow-midnight": "mi",
	"dateFormatItem-yMMMEd": "E, MMM d, y",
	"quarters-standAlone-wide": [
		"1st quarter",
		"2nd quarter",
		"3rd quarter",
		"4th quarter"
	],
	"dayPeriods-format-wide-evening1": "in the evening",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-tue-short-relative+0": "this Tue.",
	"field-tue-short-relative+1": "next Tue.",
	"field-month-short-relative+-1": "last mo.",
	"field-mon-relative+-1": "last Monday",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "month",
	"dayPeriods-standAlone-abbr-night1": "night",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min.",
	"field-dayperiod": "am/pm",
	"field-sat-short-relative+0": "this Sat.",
	"field-sat-short-relative+1": "next Sat.",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "MMM d, y",
	"eraAbbr": [
		"BC",
		"AD"
	],
	"dayPeriods-format-abbr-pm": "PM",
	"field-mon-relative+0": "this Monday",
	"field-mon-relative+1": "next Monday",
	"field-year-short": "yr.",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"dayPeriods-format-wide-morning1": "in the morning",
	"field-quarter-relative+-1": "last quarter",
	"days-format-short": [
		"Su",
		"Mo",
		"Tu",
		"We",
		"Th",
		"Fr",
		"Sa"
	],
	"dayPeriods-format-wide-pm": "PM",
	"field-dayOfYear": "day of year",
	"field-sat-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-long": "{1} 'at' {0}",
	"dateFormatItem-Md": "M/d",
	"field-hour": "hour",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"months-format-wide": [
		"January",
		"February",
		"March",
		"April",
		"May",
		"June",
		"July",
		"August",
		"September",
		"October",
		"November",
		"December"
	],
	"dayPeriods-format-wide-night1": "at night",
	"dateFormat-full": "EEEE, MMMM d, y",
	"field-month-relative+-1": "last month",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "qtr.",
	"field-sat-narrow-relative+0": "this Sa",
	"dateFormatItem-Hmv": "HH:mm v",
	"field-fri-relative+0": "this Friday",
	"field-sat-narrow-relative+1": "next Sa",
	"field-fri-relative+1": "next Friday",
	"dateFormatItem-EBhm": "E h:mm B",
	"dayPeriods-format-narrow-noon": "n",
	"field-sun-short-relative+0": "this Sun.",
	"field-sun-short-relative+1": "next Sun.",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-week-relative+-1": "last week",
	"field-quarter-short-relative+-1": "last qtr.",
	"dateFormatItem-Ehm": "E h:mm a",
	"months-format-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"May",
		"Jun",
		"Jul",
		"Aug",
		"Sep",
		"Oct",
		"Nov",
		"Dec"
	],
	"dayPeriods-format-wide-midnight": "midnight",
	"field-quarter-relative+0": "this quarter",
	"field-minute-relative+0": "this minute",
	"timeFormat-long": "h:mm:ss a z",
	"field-quarter-relative+1": "next quarter",
	"field-wed-short-relative+-1": "last Wed.",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormat-short": "M/d/yy",
	"dateFormatItem-Bh": "h B",
	"field-thu-short-relative+-1": "last Thu.",
	"dayPeriods-format-abbr-night1": "at night",
	"dateFormatItem-MMMMW": "'week' W 'of' MMMM",
	"days-standAlone-wide": [
		"Sunday",
		"Monday",
		"Tuesday",
		"Wednesday",
		"Thursday",
		"Friday",
		"Saturday"
	],
	"field-mon-narrow-relative+-1": "last M",
	"dateTimeFormats-appendItem-Era": "{0} {1}",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-thu-narrow-relative+-1": "last Th",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "wk. of mo.",
	"field-tue-narrow-relative+-1": "last Tu",
	"dayPeriods-format-abbr-evening1": "in the evening",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "this Wed.",
	"months-standAlone-wide": [
		"January",
		"February",
		"March",
		"April",
		"May",
		"June",
		"July",
		"August",
		"September",
		"October",
		"November",
		"December"
	],
	"field-wed-short-relative+1": "next Wed.",
	"dateFormatItem-Hmsv": "HH:mm:ss v",
	"field-sun-relative+-1": "last Sunday",
	"dateTimeFormat-full": "{1} 'at' {0}",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "day of the week",
	"dayPeriods-standAlone-wide-evening1": "evening",
	"field-sat-relative+0": "this Saturday",
	"dateFormatItem-h": "h a",
	"field-sat-relative+1": "next Saturday",
	"field-week-short-relative+0": "this wk.",
	"dateFormatItem-hmsv": "h:mm:ss a v",
	"field-week-short-relative+1": "next wk.",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"May",
		"Jun",
		"Jul",
		"Aug",
		"Sep",
		"Oct",
		"Nov",
		"Dec"
	],
	"dayPeriods-format-abbr-morning1": "in the morning",
	"field-month-short-relative+0": "this mo.",
	"timeFormat-full": "h:mm:ss a zzzz",
	"field-month-short-relative+1": "next mo.",
	"field-weekdayOfMonth-short": "wkday. of mo.",
	"dateFormatItem-MEd": "E, M/d",
	"dateFormatItem-y": "y",
	"field-thu-narrow-relative+0": "this Th",
	"field-sun-narrow-relative+-1": "last Su",
	"field-mon-short-relative+-1": "last Mon.",
	"field-thu-narrow-relative+1": "next Th",
	"field-thu-relative+0": "this Thursday",
	"dayPeriods-standAlone-abbr-afternoon1": "afternoon",
	"field-thu-relative+1": "next Thursday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Fri.",
	"dateFormatItem-hmv": "h:mm a v",
	"dayPeriods-format-abbr-noon": "noon",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-thu-relative+-1": "last Thursday",
	"dateFormatItem-yMd": "M/d/y",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-week": "week",
	"quarters-format-wide": [
		"1st quarter",
		"2nd quarter",
		"3rd quarter",
		"4th quarter"
	],
	"dateFormatItem-Ed": "d E",
	"field-wed-narrow-relative+0": "this W",
	"field-wed-narrow-relative+1": "next W",
	"dayPeriods-standAlone-wide-morning1": "morning",
	"field-year-short-relative+0": "this yr.",
	"field-dayperiod-short": "am/pm",
	"field-year-short-relative+1": "next yr.",
	"field-fri-short-relative+0": "this Fri.",
	"field-fri-short-relative+1": "next Fri.",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"days-standAlone-short": [
		"Su",
		"Mo",
		"Tu",
		"We",
		"Th",
		"Fr",
		"Sa"
	],
	"field-week-short-relative+-1": "last wk.",
	"dayPeriods-format-abbr-midnight": "midnight",
	"field-hour-short": "hr.",
	"field-zone-short": "zone",
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-fri-narrow-relative+-1": "last F",
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-fri-relative+-1": "last Friday",
	"eraNarrow": [
		"B",
		"A"
	],
	"dateFormatItem-Bhms": "h:mm:ss B",
	"dayPeriods-format-wide-noon": "noon",
	"field-tue-short-relative+-1": "last Tue.",
	"dayPeriods-standAlone-wide-afternoon1": "afternoon",
	"dateFormatItem-yQQQ": "QQQ y",
	"days-format-wide": [
		"Sunday",
		"Monday",
		"Tuesday",
		"Wednesday",
		"Thursday",
		"Friday",
		"Saturday"
	],
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"field-mon-narrow-relative+0": "this M",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "next M",
	"dayPeriods-standAlone-wide-midnight": "midnight",
	"field-year-short-relative+-1": "last yr.",
	"dateFormatItem-yM": "M/y",
	"field-zone": "time zone",
	"dateFormatItem-yMMMM": "MMMM y",
	"dateFormatItem-MMMEd": "E, MMM d",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-yMEd": "E, M/d/y",
	"dayPeriods-standAlone-abbr-am": "AM",
	"field-day-relative+-1": "yesterday",
	"field-sun-short-relative+-1": "last Sun.",
	"dayPeriods-format-narrow-night1": "at night",
	"field-weekday-short": "day of wk.",
	"dateFormatItem-Bhm": "h:mm B",
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"dateFormatItem-yMMMd": "MMM d, y",
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"dateFormatItem-Gy": "y G",
	"field-era": "era",
	"field-day-short": "day",
	"dayPeriods-standAlone-abbr-evening1": "evening",
	"field-fri-narrow-relative+0": "this F",
	"dayPeriods-format-narrow-evening1": "in the evening",
	"field-fri-narrow-relative+1": "next F",
	"dayPeriods-standAlone-wide-am": "AM"
}
//end v1.x content
);